aboutsummaryrefslogtreecommitdiff
path: root/sys/dev/buslogic
diff options
context:
space:
mode:
authorPedro F. Giffuni <pfg@FreeBSD.org>2016-05-03 03:41:25 +0000
committerPedro F. Giffuni <pfg@FreeBSD.org>2016-05-03 03:41:25 +0000
commit453130d9bfc1c6d68b366dfcb041689d69f81295 (patch)
treefe36ef227324b313676d43aef9a4d97c9a09675a /sys/dev/buslogic
parent7860c0c3843dbb1cf8f4f2c20ee526e8dd2661da (diff)
Notes
Diffstat (limited to 'sys/dev/buslogic')
-rw-r--r--sys/dev/buslogic/bt.c8
-rw-r--r--sys/dev/buslogic/bt_eisa.c2
2 files changed, 5 insertions, 5 deletions
diff --git a/sys/dev/buslogic/bt_eisa.c b/sys/dev/buslogic/bt_eisa.c
index 6a61d7a21f8b..e68d2f77be28 100644
--- a/sys/dev/buslogic/bt_eisa.c
+++ b/sys/dev/buslogic/bt_eisa.c
@@ -78,7 +78,7 @@ __FBSDID("$FreeBSD$");
#define EISA_IRQ_TYPE 0x08D
#define LEVEL 0x40
-/* Definitions for the AMI Series 48 controler */
+/* Definitions for the AMI Series 48 controller */
#define AMI_EISA_IOSIZE 0x500 /* Two separate ranges?? */
#define AMI_EISA_SLOT_OFFSET 0x800
#define AMI_EISA_IOCONF 0x000
diff --git a/sys/dev/buslogic/bt.c b/sys/dev/buslogic/bt.c
index 5276051c2494..b0a0d919a60e 100644
--- a/sys/dev/buslogic/bt.c
+++ b/sys/dev/buslogic/bt.c
@@ -1578,7 +1578,7 @@ btdone(struct bt_softc *bt, struct bt_ccb *bccb, bt_mbi_comp_code_t comp_code)
struct ccb_hdr *ccb_h;
cam_status error;
/* Notify all clients that a BDR occured */
error = xpt_create_path(&path, /*periph*/NULL,
cam_sim_path(bt->sim),
bccb->hccb.target_id,
@@ -1624,12 +1624,12 @@ btdone(struct bt_softc *bt, struct bt_ccb *bccb, bt_mbi_comp_code_t comp_code)
case BMBI_ABORT:
case BMBI_ERROR:
if (bootverbose) {
- printf("bt: ccb %p - error %x occured. "
+ printf("bt: ccb %p - error %x occurred. "
"btstat = %x, sdstat = %x\n",
(void *)bccb, comp_code, bccb->hccb.btstat,
bccb->hccb.sdstat);
}
/* An error occured */
switch(bccb->hccb.btstat) {
case BTSTAT_DATARUN_ERROR:
if (bccb->hccb.data_len == 0) {
@@ -2317,7 +2317,7 @@ bttimeout(void *arg)
* means that the driver attempts to clear only one error
* condition at a time. In general, timeouts that occur
* close together are related anyway, so there is no benefit
- * in attempting to handle errors in parrallel. Timeouts will
+ * in attempting to handle errors in parallel. Timeouts will
* be reinstated when the recovery process ends.
*/
if ((bccb->flags & BCCB_DEVICE_RESET) == 0) {
@@ -1578,7 +1578,7 @@ btdone(struct bt_softc *bt, struct bt_ccb *bccb, bt_mbi_comp_code_t comp_code)
struct ccb_hdr *ccb_h;
cam_status error;
- /* Notify all clients that a BDR occured */
+ /* Notify all clients that a BDR occurred */
error = xpt_create_path(&path, /*periph*/NULL,
cam_sim_path(bt->sim),
@@ -1624,12 +1624,12 @@ btdone(struct bt_softc *bt, struct bt_ccb *bccb, bt_mbi_comp_code_t comp_code)
bccb->hccb.sdstat);
}
- /* An error occured */
+ /* An error occurred */
switch(bccb->hccb.btstat) {
case BTSTAT_DATARUN_ERROR: